NEXTorr - Heros Devices 0.8.0 documentation

Skip to content
Back to top
View this page

# NEXTorr

From: SAES Getters

Class: `herosdevices.hardware.saes.nextorr.NEXTorr`

Driver Quality Index: beta

A NEXTorr vacuum pump with serial based connection.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.saes.nextorr.NEXTorr` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
device | <class ‘str’> |  | Serial device address. Typically /dev/ttyUSB0 or similar.
baudrate | <class ‘int’> | 115200 |

The following JSON strings can be used to start a HERO device representation of `NEXTorr` using BOSS.

    {
        "_id": "my_NEXTorr",
        "classname": "herosdevices.hardware.saes.nextorr.NEXTorr",
        "arguments": {
            "device": "<class 'str'>",
            "baudrate": 115200
        }
    }

generated from signature